"regi" method (sarpy.processing.registration.regi)
==================================================

.. automodule:: sarpy.processing.registration.regi
    :members:
    :show-inheritance:
    :inherited-members:
